@@ -1,4 +1,4 @@
-from unipipeline.brokers.uni_amqp_py_broker import UniAmqpPyBroker
+from ul_unipipeline.brokers.uni_amqp_py_broker import UniAmqpPyBroker
 
 from data_aggregator_sdk.runtime_conf import get_broker_uri
 
