@@ -214,6 +214,8 @@ class GeneralDeviceValueModel(BaseModel):
 class ShortDeviceMeterValuesModel(BaseModel):
     device_meter_ids: List[UUID] = Field(title='Device Meter ID list', description='array of device meter ids')
 
+class ShortDeviceChannelValuesModel(BaseModel):
+    device_channel_ids: List[UUID] = Field(title='Device Channel ID list', description='array of device channel ids')
 
 class GeneralDeviceMeterValueModel(BaseModel):
     devices_meter: List[GeneralDeviceMeterValueDescriptionModel] = Field(title='GeneralDeviceValueDescriptionModels', description='array of GeneralDeviceValueDescriptionModel')
@@ -270,6 +272,18 @@ class GeneralApiDeviceValueResponse(BaseModel):
     )
 
 
+class ShortDeviceMeterValuesResponse(JsonApiResponsePayload):
+    device_channel_ids: List[UUID] = Field(title='Device Channel ID list', description='array of device channel ids')
+
+
+class ShortDeviceChannelLastValuesResponse(BaseModel):
+    device_channel_id: UUID = Field(title='Device Channel ID list', description='array of device channel ids')
+    last_value: Optional[float] = Field(None, title='Last Value', description='last value')
+    last_value_date: Optional[datetime] = Field(None, title='Last Value Date', description='last value date')
+
+class ShortDeviceChannelLastValuesListResponse(JsonApiResponsePayload):
+    device_channels: List[ShortDeviceChannelLastValuesResponse]
+
 class GeneralApiDeviceMeterValueResponse(JsonApiResponsePayload):
     meter_id: UUID = Field(title='Meter Id', description='meter identifier')
     kind: ResourceKind = Field(title='Kind', description=f'Kind ({", ".join(kind.name for kind in ResourceKind)})')
@@ -298,6 +312,16 @@ class ApiDeviceLowBatteryResponse(JsonApiResponsePayload):
     last_value_date: Optional[datetime] = Field(None, title='Last Value Date', description='last value date')
 
 
+class ApiDeviceBatteriesResponse(JsonApiResponsePayload):
+    device_id: UUID4 = Field(title='Device Identifier', description='device unique identifier')
+    manufacturer_serial_number: str = Field(title='Manufacturer Serial Number', description='device manufacturer serial number')
+    device_modification_name: Optional[str] = Field(None, title='Device Modification Name', description='name of device modification')
+    device_modification_type_name: Optional[str] = Field(None, title='Device Modification Type Name', description='name of device type modification')
+    date: datetime = Field(title='Date', description='date of the battery value')
+    battery_id: int = Field(title='Battery Identifier', description='device battery identifier')
+    battery_value: float = Field(title='Battery value', description='battery value (volts')
+
+
 class ApiDeviceResponse(ApiBaseUserModelPayloadResponse):
     manufacturer_serial_number: str = Field(title='Manufacturer Serial Number', description='manufacturer serial number')
     firmware_version: Optional[str] = Field(None, title='Firmware Version', description='firmware version')
@@ -1057,6 +1081,30 @@ class DataAggregatorApiSdk:
             'is_filter_by_period_timezone': is_filter_by_period_timezone,
         }).typed(List[GeneralApiDeviceMeterValueResponse]).check().payload
 
+    '''used in services: Iot Account Application Backend'''
+    @internal_api_error_handler
+    def get_list_device_channel_no_data(
+        self,
+        period_from: date | datetime,
+        period_to: date | datetime,
+        devices_channel: ShortDeviceChannelValuesModel,
+    ) -> ShortDeviceMeterValuesResponse:
+        return self._api_device.request_post('/devices/no-data/period', json=devices_channel, q={
+            'period_from': period_from,
+            'period_to': period_to,
+        }).typed(ShortDeviceMeterValuesResponse).check().payload
+
+    '''used in services: Iot Account Application Backend'''
+    @internal_api_error_handler
+    def get_list_device_last_value_by_date(
+        self,
+        date_selection: date | datetime,
+        devices_channel: ShortDeviceChannelValuesModel,
+    ) -> ShortDeviceChannelLastValuesListResponse:
+        return self._api_device.request_post('/devices/no-data/last-value', json=devices_channel, q={
+            'date_selection': date_selection,
+        }).typed(ShortDeviceChannelLastValuesListResponse).check().payload
+
     '''used in services: Iot Account Application Backend'''
     @internal_api_error_handler
     def get_daily_values_value_for_devices_meter(
@@ -1087,6 +1135,24 @@ class DataAggregatorApiSdk:
             'iteration_interval': iteration_interval.value if iteration_interval is not None else None,
         }).typed(List[ApiDeviceLowBatteryResponse]).check().payload
 
+    '''used in services: Data Reporter'''
+    @internal_api_error_handler
+    def get_device_sensor_battery_list(
+        self,
+        battery_threshold: Optional[float] = None,
+        battery_id: Optional[int] = None,
+        device_modifications: Optional[List[UUID]] = None,
+        device_metering_types: Optional[List[UUID]] = None,
+        macs: Optional[List[int]] = None,
+    ) -> List[ApiDeviceBatteriesResponse]:
+        return self._api_device.request_post('/devices/device-sensors/batteries-monitoring', json={
+            'battery_threshold': battery_threshold,
+            'battery_id': battery_id,
+            'device_modifications': device_modifications,
+            'device_metering_types': device_metering_types,
+            'macs': macs,
+        }).typed(List[ApiDeviceBatteriesResponse]).check().payload
+
     '''used in services: Iot Account Application Backend'''
     @internal_api_error_handler
     def get_first_value_date_for_devices(
