@@ -1,16 +1,17 @@
 from datetime import datetime, date, time
 from decimal import Decimal
 from enum import Enum, IntEnum, unique
-from typing import Optional, List, Tuple, Dict, Any
+from typing import Optional, List, Tuple, Dict
+from uuid import UUID
 
 from dateutil.relativedelta import relativedelta
-from pydantic import BaseModel, UUID4, root_validator, Field  # pylint: disable=no-name-in-module
-from ul_api_utils.errors import ValidateApiError
+from pydantic import BaseModel, UUID4, Field, model_validator  # pylint: disable=no-name-in-module
 from ul_api_utils.utils.api_method import ApiMethod
-from unipipeline.message.uni_message import UniMessage
+from ul_unipipeline.message.uni_message import UniMessage
 
 from data_aggregator_sdk.constants.enums import IntegrationV0MessageEvent, IntegrationV0MessageMetaBSChannelProtocol, \
-    ProtocolEnum, IntegrationV0MessageErrorType, DownlinkTaskStatus, JournalDataType, SensorType, DeviceValueMarker
+    ProtocolEnum, IntegrationV0MessageErrorType, DownlinkTaskStatus, JournalDataType, SensorType, DeviceValueMarker, \
+    DeviceDownlinkTaskStatus
 from data_aggregator_sdk.constants.enums import ResourceKind
 from data_aggregator_sdk.types.device import NetworkSysTypeEnum
 
@@ -491,14 +492,14 @@ class IntegrationV0MessageProfile(BaseModel):
         description="Sequence of collected values for profile packet",
     )
 
-    @root_validator
-    def validate_profile(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        granulation = values['granulation']
-        len_values = len(values['values'])
+    @model_validator(mode='after')
+    def validate_profile(self) -> 'IntegrationV0MessageProfile':
+        granulation = self.granulation
+        len_values = len(self.values)
 
         if GRANULATION_LENGTH_MAP[granulation] == len_values:
-            return values
-        raise ValidateApiError(msg=f"Incorrect profile type and granulation: Granulation is {granulation}, Length values={len_values}")
+            return self
+        raise ValueError(f"Incorrect profile type and granulation: Granulation is {granulation}, Length values={len_values}")
 
 
 class IntegrationV0MessageConsumption(BaseModel):
@@ -977,6 +978,58 @@ class IntegrationMessageMetaUniversalDataInput(BaseModel):
     )
 
 
+class BsImportProtocol(Enum):
+    nbfi = 'nbfi'
+    unbp28 = 'unbp28'
+
+
+class IntegrationMessageMetaBsHttpImport(BaseModel):
+    protocol: BsImportProtocol = Field(
+        title='Protocol',
+        description='Bs Import protocol',
+    )
+    mac: int = Field(
+        title='MAC',
+        description='Mac address of the device',
+    )
+    dt: datetime = Field(
+        title='Capture datetime',
+        description='Capture datetime',
+    )
+    rssi: int = Field(
+        title='RSSI value',
+        description='RSSI value',
+    )
+    snr: int = Field(
+        title='SNR value',
+        description='SNR value',
+    )
+    sdr: int = Field(
+        title='SDR value',
+        description='SDR value',
+    )
+    baudrate: int = Field(
+        title='Baudrate',
+        description='Baudrate',
+    )
+    channel: int = Field(
+        title='Channel',
+        description='Channel',
+    )
+    freq: int = Field(
+        title='Frequency',
+        description='Frequency',
+    )
+    station_serial_number: int = Field(
+        title="Station serial number",
+        description="Station serial number",
+    )
+    station_id: UUID4 = Field(
+        title="Station ID",
+        description="Station unique identifier",
+    )
+
+
 class IntegrationV0MessageMeta(BaseModel):
     nbfi_bs0: Optional[IntegrationV0MessageMetaNbFiBS0] = Field(
         None,
@@ -1013,20 +1066,26 @@ class IntegrationV0MessageMeta(BaseModel):
         title="Recycle info",
         description="Structure which contains integration message recycle date",
     )
+    bs_http_import: Optional[IntegrationMessageMetaBsHttpImport] = Field(
+        None,
+        title="BS HTTP Import meta message",
+        description="BS HTTP Import meta message structure",
+    )
 
-    @root_validator()
-    def check_meta_exists(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+    @model_validator(mode='after')
+    def check_meta_exists(self) -> 'IntegrationV0MessageMeta':
         if not any((
-            values.get('nbfi_bs0'),
-            values.get('nbiot'),
-            values.get('bs_http'),
-            values.get('external_api_data_input'),
-            values.get('universal_data_input'),
-            values.get('iot_account_gateway'),
-            values.get('recycle'),
+            self.nbfi_bs0,
+            self.nbiot,
+            self.bs_http,
+            self.external_api_data_input,
+            self.universal_data_input,
+            self.iot_account_gateway,
+            self.recycle,
+            self.bs_http_import,
         )):
-            raise ValueError('one of meta sctructure must be set')
-        return values
+            raise ValueError('one of meta structure must be set')
+        return self
 
 
 class IntegrationV0MessageError(BaseModel):
@@ -1178,11 +1237,11 @@ class ManagementInputV0MessageData(BaseModel):
         title="Effective date",
         description="Effective date",
     )
-    bs_downlink_task_id: UUID4 = Field(
+    bs_downlink_task_id: UUID = Field(
         title="Task ID",
         description="Task ID",
     )
-    status: DownlinkTaskStatus = Field(
+    status: DownlinkTaskStatus | DeviceDownlinkTaskStatus = Field(
         title="Downlink task status",
         description="Downlink task status",
     )
@@ -1195,6 +1254,11 @@ class ManagementInputV0MessageData(BaseModel):
         title="User ID",
         description="ID of the user who created the changes",
     )
+    mac: Optional[int] = Field(
+        None,
+        title="Mac of the device in case of task execution",
+        description="Filled only when task is executed",
+    )
 
 
 class ManagementInputV0Message(UniMessage):
