@@ -1,6 +1,6 @@
 import os
 
-from unipipeline.modules.uni import Uni
+from ul_unipipeline.modules.uni import Uni
 
 CONFIG_FILE = os.path.join(os.path.dirname(os.path.abspath(__file__)), "dag.yml")
 
