@@ -2,8 +2,8 @@ from datetime import datetime
 from typing import Any, Dict, List, Optional
 from uuid import UUID
 
-from ul_api_utils.api_resource.api_response_payload_alias import ApiBaseUserModelPayloadResponse
 from ul_api_utils.api_resource.api_response import JsonApiResponsePayload
+from ul_api_utils.api_resource.api_response_payload_alias import ApiBaseUserModelPayloadResponse
 
 from data_aggregator_sdk.constants.enums import DeviceModificationTypeEnum, NetworkSysTypeEnum, NetworkTypeEnum, \
     ProtocolEnum, ResourceKind
@@ -19,8 +19,8 @@ class ApiDataGatewaysNetworkResponse(ApiBaseUserModelPayloadResponse):
     data_gateway_id: UUID
     data_gateway: ApiDataGatewayResponse
     sys_type: NetworkSysTypeEnum
-    specifier: Optional[str]
-    params: Optional[Dict[str, Any]]
+    specifier: Optional[str] = None
+    params: Optional[Dict[str, Any]] = None
 
 
 class ApiProtocolResponse(JsonApiResponsePayload):
@@ -39,13 +39,13 @@ class ApiDataGatewayNetworkDevicePayloadResponse(JsonApiResponsePayload):
     downlink_protocol_id: UUID
     data_gateway_network_id: UUID
     mac: int
-    key_id: Optional[UUID]
+    key_id: Optional[UUID] = None
     device_id: UUID
-    uplink_encryption_key: Optional[str]
-    downlink_encryption_key: Optional[str]
-    encryption_key: Optional[str]
+    uplink_encryption_key: Optional[str] = None
+    downlink_encryption_key: Optional[str] = None
+    encryption_key: Optional[str] = None
     protocol: ApiProtocolResponse
-    network: Optional[ApiDataGatewaysNetworkResponse]
+    network: Optional[ApiDataGatewaysNetworkResponse] = None
 
 
 class ApiDeviceMeteringTypeResponse(JsonApiResponsePayload):
@@ -75,20 +75,20 @@ class ApiDeviceModificationResponse(JsonApiResponsePayload):
     id: UUID
     date_created: datetime
     date_modified: datetime
-    name: Optional[str]
-    device_modification_type_id: Optional[UUID]
+    name: Optional[str] = None
+    device_modification_type_id: Optional[UUID] = None
     device_modification_type: ApiDeviceModificationTypeResponse
 
 
 class ApiDeviceMeterPayloadResponse(ApiBaseUserModelPayloadResponse):
     device_channel_id: UUID
-    value_multiplier: Optional[float]
-    unit_multiplier: Optional[float]
+    value_multiplier: Optional[float] = None
+    unit_multiplier: Optional[float] = None
     kind: ResourceKind
 
 
 class ApiDeviceChannelPayloadResponse(ApiBaseUserModelPayloadResponse):
-    inactivity_limit: Optional[int]
+    inactivity_limit: Optional[int] = None
     serial_number: int
     device_meter: List[ApiDeviceMeterPayloadResponse]
 
@@ -103,10 +103,10 @@ class ApiDeviceManufacturerResponse(JsonApiResponsePayload):
 
 class ApiImportDeviceResponse(ApiBaseUserModelPayloadResponse):
     manufacturer_serial_number: str
-    firmware_version: Optional[str]
-    hardware_version: Optional[str]
-    date_produced: Optional[datetime]
+    firmware_version: Optional[str] = None
+    hardware_version: Optional[str] = None
+    date_produced: Optional[datetime] = None
     device_manufacturer: ApiDeviceManufacturerResponse
     device_modification: ApiDeviceModificationResponse
     device_channel: List[ApiDeviceChannelPayloadResponse]
-    data_gateway_network_device: Optional[ApiDataGatewayNetworkDevicePayloadResponse]
+    data_gateway_network_device: Optional[ApiDataGatewayNetworkDevicePayloadResponse] = None
